pub struct DecafPoint(pub(crate) ExtendedPoint);Expand description
A Decaf point in the Twisted Edwards curve
Tuple Fields
0: ExtendedPointImplementations
Sourceimpl DecafPoint
impl DecafPoint
Sourcepub const GENERATOR: DecafPoint
pub const GENERATOR: DecafPoint
The generator point
Sourcepub const IDENTITY: DecafPoint
pub const IDENTITY: DecafPoint
The identity point
Sourcepub fn is_identity(&self) -> Choice
pub fn is_identity(&self) -> Choice
Check if the point is the identity
Sourcepub fn add(&self, other: &DecafPoint) -> DecafPoint
pub fn add(&self, other: &DecafPoint) -> DecafPoint
Add two points
Sourcepub fn sub(&self, other: &DecafPoint) -> DecafPoint
pub fn sub(&self, other: &DecafPoint) -> DecafPoint
Subtract two points
Sourcepub fn compress(&self) -> CompressedDecaf
pub fn compress(&self) -> CompressedDecaf
Compress this point
Sourcepub fn from_uniform_bytes(bytes: &[u8; 112]) -> Self
pub fn from_uniform_bytes(bytes: &[u8; 112]) -> Self
Construct a DecafPoint from 112 bytes of data.
If the input bytes are uniformly distributed, the resulting point will be uniformly distributed over the group, and its discrete log with respect to other points is unknown.
Implements map to curve according see https://datatracker.ietf.org/doc/rfc9380/ section 5.3.4 by splitting the input into two 56-byte halves, then applies the decaf448_map to each, and adds the results.