pub struct PublicKeyBytes(pub [u8; 57]);Expand description
Ed448 public key serialized as bytes.
This type is primarily useful for decoding/encoding SPKI public key files (either DER or PEM) encoded using the following traits:
DecodePublicKey: decode DER or PEM encoded PKCS#8 private key.EncodePublicKey: encode DER or PEM encoded PKCS#8 private key.
SPKI public key files encoded with PEM begin with:
-----BEGIN PUBLIC KEY-----Note that this type operates on raw bytes and performs no validation that public keys represent valid compressed Ed448 y-coordinates.
Tuple Fields
0: [u8; 57]Implementations