#[repr(C)]pub struct Signature {
pub(crate) R: [u8; 57],
pub(crate) s: [u8; 57],
}Expand description
Ed448 signature.
This type represents a container for the byte serialization of an Ed448 signature, and does not necessarily represent well-formed field or curve elements.
Signature verification libraries are expected to reject invalid field elements at the time a signature is verified.
Fields
R: [u8; 57]s: [u8; 57]Implementations